.. _ref_meshing_guide:

================
Meshing workflow
================
The guided workflows in Fluent meshing are designed to make it easier to generate a
volume mesh starting from CAD geometries. You can use PyFluent to access the guided workflows.

Workflows are divided into the new :ref:`ref_new_meshing_workflows_guide` and :ref:`ref_meshing_workflows_guide`, which align with the journal syntax.

.. toctree::
   :maxdepth: 1
   :hidden:

   meshing_workflows
   new_meshing_workflows